===============================
Text Toolkit: txttk
===============================

.. image:: https://img.shields.io/travis/jeroyang/txttk.svg
        :target: https://travis-ci.org/jeroyang/txttk

.. image:: https://img.shields.io/pypi/v/txttk.svg
        :target: https://pypi.python.org/pypi/txttk


Text Toolkit: manipulate text & regular expression

Installation and Update
------------

.. code:: bash

    $ pip install -U txttk

Usage
-----

Module *corpus*
~~~~~~~~~~~~~~~

.. code:: python
    from txttk import corpus

    from txttk import feature
    from txttk import nlptools
    from txttk import report
    from txttk import retools

Features
--------
* corpus: Handle the corpus, make random division for cross validation
* feature: Extract features from a given token
* nlptools: Nature Language Processing tools.
* retools: Manipulate Regular Expression strings.


License
---------
* Free software: BSD license
* Documentation: https://txttk.readthedocs.org.
